import stan
import arviz as az
import pickle

StanScript = """
    functions {
        real hnormal_lpdf(real y, real mu, real sgm) {
            if (y > mu) {
                return normal_lpdf(y|mu, sgm) + log(2.0);
            }
            else {
                return negative_infinity();
            }
        }
    }
    data {
        real mu;
        real<lower=0> sgm;
    }
    parameters {
        real a;
        real b;
    }
    model {
        a ~ normal(mu, sgm);
        //target += hnormal_lpdf(b|mu, sgm);
        b ~ hnormal(mu, sgm);
    }
"""

sm = stan.build(StanScript,data = {'mu':1.0, 'sgm':2.0} )
print('OK!')

fit = sm.sample( num_samples = 10000)
print(fit)
print('Statistics...\n',
      az.summary(az.from_pystan(posterior = fit, posterior_model = sm)))

with open('fita.pkl', 'wb') as f:
    pickle.dump(fit['a'], f)
with open('fitb.pkl', 'wb') as f:
    pickle.dump(fit['b'], f)
